@@ -24,8 +24,10 @@ dispatch_table_store: Dict = {}
 
 
 def types_lookup(type_name: str) -> Optional[Any]:
-    # helper function to get a type.
-    # if type_name does not exist (because of the Python version), return None
+    """Get a type from name.
+    
+    If type_name does not exist (because of the Python version), return None.
+    """
     return getattr(types, type_name, None)
 
 
@@ -316,7 +318,7 @@ def signif_object(obj: Any, digits: int = 3, use_copy: bool = False):
 
 
 def map_object(
-    map_function: Callable[[IntOrFloat], IntOrFloat],
+    map_function: Callable[[Number], Number],
     obj: Any,
     use_copy: bool = False,
 ):
