@@ -1,4 +1,7 @@
 import pytest
+import fractions
+import decimal
+
 from copy import deepcopy
 
 
@@ -38,3 +41,14 @@ def complex_object():
         },
     }
     return deepcopy(obj)
+
+@pytest.fixture()
+def object_with_various_numbers():
+    obj = {
+        "complex number": 1.2-2j,
+        "string": "something nice, ha?",
+        "callable": lambda x: x ** 2,
+        "decimal": decimal.Decimal("1.2"),
+        "fraction": fractions.Fraction(1, 4),
+    }
+    return deepcopy(obj)
